import { Box3, Matrix4 } from "three";
import { CADObject } from "../../../DatabaseServices/CADObject";
import { Board } from "../../../DatabaseServices/Entity/Board";
import { Entity } from '../../../DatabaseServices/Entity/Entity';
import { HardwareCompositeEntity } from "../../../DatabaseServices/Hardware/HardwareCompositeEntity";
import { ObjectId } from "../../../DatabaseServices/ObjectId";
import { TemplateRecord } from "../../../DatabaseServices/Template/TemplateRecord";
import { ISpaceParse } from "../../../Geometry/SpaceParse/ISpaceParse";
import { BoardProcessOption } from "../../../UI/Store/BoardInterface";
import { DoorStore } from "../../../UI/Store/DoorDrawerStore/DoorStore";
import { IDoorConfigOption, IDoorInfo } from "../../../UI/Store/DoorInterface";
export declare class DrawDoorTool {
    private store;
    protected spaceParse: ISpaceParse;
    /**id模板对应表*/
    protected _idTempMap: Map<string, TemplateRecord>;
    protected colWidths: (number | string)[];
    protected rowHeighs: (number | string)[];
    protected isDrawVerBrS: boolean[];
    protected isDrawLayBrS: boolean[];
    protected surroundOption: BoardProcessOption;
    /** 每个格子的信息Map*/
    protected rowColIdMap: Map<string, IDoorInfo>;
    private hingeSet;
    protected option: IDoorConfigOption;
    protected doorInfos: IDoorInfo[];
    private currentHandleProps;
    constructor(store: DoorStore, spaceParse: ISpaceParse);
    private GetHeightExpr;
    protected Init(): Promise<void>;
    Draw(): Promise<void>;
    protected AppendTemplateParam(name: string, value: number, des: string, temp: TemplateRecord, expr?: string): void;
    protected GetRootTemplate(): TemplateRecord;
    private CreatePositionSpaceTr;
    protected CreateHandleTr(info: IDoorInfo, doorTr: TemplateRecord): void;
    protected GetHingeTemp(info: IDoorInfo, door: TemplateRecord): boolean;
    /**
     * 设置五金(拉手 铰链)和板的关联切割
     * @param allEntitys 所有的实体 包括了门和五金
     * @param isUpDownDoor 上下开门 否为左右开门
     * @returns
     */
    protected RelativeMetalsToBoard(allEntitys: Entity[], isUpDownDoor: boolean): boolean;
    getSpaceAllBoards(): Board[];
    protected GetDoorTemp(info: IDoorInfo): TemplateRecord;
    protected SetOpenDir(doorsTemp: TemplateRecord, info: IDoorInfo): void;
    private GetBoardOpenDir;
    /**
     *上下偏移判断位置是否超出门板 或与其他层板碰撞 上下/左右 尝试n个单位后停止
     *
     * @private
     * @param {number} doorSpecs  门板高度/宽度
     * @param {Box3} inventedBox        铰链空间box  GetBoundingBoxInMtx
     * @param {Entity[]} checkEnts      判断碰撞板
     * @param {number} distance   一次偏移量
     * @param {Matrix4} ocs
     * @param {number} number     偏移次数  正负表方向 上下或左右
     * @return {*}  {number}
     * @memberof DrawDoorTool
     */
    private GetHingeMoveNum;
    private MoveAgain;
}
/**
 * 设置未被分析铰链类型的铰链  都设置成无盖铰链
 * @param parseTypedHinges 已经解析了类型的铰链
 * @param hingeSet
 */
export declare function SetNoPareTypeHigneName(parseTypedHinges: Set<ObjectId<CADObject>>, hingeSet: Set<ObjectId<CADObject>>): void;
/**
 * 设置铰链的类型(全盖 无盖 半盖)
 * @param br
 * @param ironware
 * @returns void
 */
export declare function SetHingeType(br: Board, ironware: HardwareCompositeEntity): void;
/**
 * @param enBox 实体的世界坐标系盒子
 * @param checkEnts 校验的实体列表
 * @param parentOCS 父空间的坐标系
 */
export declare function IsBoxAndEntitysIntersect(enBox: Box3, checkEnts: Entity[], parentOCS?: Matrix4): boolean;
/**
 *
 * 特殊铰链模板（多个实体编组）
 * 防止 hingeSpace.GetParam("SY").value 被覆盖
 *
 * @param {Map<ObjectId, number>} hingeTr2Size_Map
 * @param {TemplateRecord} hingeTr
 * @param {number} sizeX 编组内size取最大的 (宽度?)
 * @return {*}  {boolean} 如果记录过了(并且尺寸比新来的大) 就返回true
 */
export declare function RecordHingeTrSizeX(hingeTr2Size_Map: Map<ObjectId, number>, hingeTr: TemplateRecord, sizeX: number): boolean;
//# sourceMappingURL=DrawDoorTool.d.ts.map